//===============================================================================
// Microsoft patterns & practices Enterprise Library
// Data Access Application Block
//===============================================================================
// Copyright  Microsoft Corporation.  All rights reserved.
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY
// OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE.
//===============================================================================

#if  UNIT_TESTS
using System.Data;
using System.Data.OleDb;
using Microsoft.Practices.EnterpriseLibrary.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Data.Tests;
using Microsoft.Practices.EnterpriseLibrary.Data.AddOns.Tests;
using NUnit.Framework;

namespace Microsoft.Practices.EnterpriseLibrary.Data.AddOns.OleDb.Tests
{
	[TestFixture]
	public class OleDbDatabaseFixture
	{
		private static ConfigurationContext context = new OleDbTestConfigurationContext();

		[Test]
		public void ConnectionTest()
		{
			OleDbDatabase oleDbDatabase = new OleDbDatabase();
			oleDbDatabase.ConfigurationName = "NewDatabase";
			oleDbDatabase.Initialize(new DatabaseConfigurationView(context));

			IDbConnection connection = oleDbDatabase.GetConnection();
			Assert.IsNotNull(connection);
			Assert.IsTrue(connection is OleDbConnection);
			connection.Open();
		    DBCommandWrapper cmd = oleDbDatabase.GetSqlStringCommandWrapper("Select * from Region");
			cmd.CommandTimeout = 60;
			Assert.AreEqual(cmd.CommandTimeout, 60);
		}

		[Test]
		public void CanGetConnectionWithoutCredentials()
		{
			OleDbDatabase oleDbDatabase = new OleDbDatabase();
			oleDbDatabase.ConfigurationName = "DbWithSqlServerAuthn";
			oleDbDatabase.Initialize(new DatabaseConfigurationView(context));
			Assert.AreEqual("provider=sqloledb;data source=localhost;database=northwind;", oleDbDatabase.GetConnectionStringWithoutCredentials());
		}

		[Test]
		public void CanGetConnectionForStringWithNoCredentials()
		{
			OleDbDatabase oleDbDatabase = new OleDbDatabase();
			oleDbDatabase.ConfigurationName = "NewDatabase";
			oleDbDatabase.Initialize(new DatabaseConfigurationView(context));

			Assert.AreEqual("provider=sqloledb;data source=localhost;database=northwind;", oleDbDatabase.GetConnectionStringWithoutCredentials());
		}
	}
}

#endif