//===============================================================================
// Microsoft patterns & practices Enterprise Library
// Data Access Application Block
//===============================================================================
// Copyright  Microsoft Corporation.  All rights reserved.
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY
// OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE.
//===============================================================================

#if  UNIT_TESTS

using Microsoft.Practices.EnterpriseLibrary.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Data.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Data.AddOns.OleDb;

namespace Microsoft.Practices.EnterpriseLibrary.Data.AddOns.Tests
{
	public class OleDbTestConfigurationContext : ConfigurationContext
	{
		private static ConfigurationDictionary dictionary;

		public OleDbTestConfigurationContext()
			: base( GenerateConfigurationDictionary())
		{
		}

		private static ConfigurationDictionary GenerateConfigurationDictionary()
		{
			if( dictionary == null )
			{
				dictionary = new ConfigurationDictionary();
				dictionary.Add(ConfigurationSettings.SectionName, GenerateConfigurationSettings());
				dictionary.Add(DatabaseSettings.SectionName, GenerateDataSettings());
			}
			return dictionary;
		}

		private static ConfigurationSettings GenerateConfigurationSettings()
		{
			ConfigurationSettings settings = new ConfigurationSettings();
			settings.ConfigurationSections.Add(new ConfigurationSectionData(DatabaseSettings.SectionName, false, new XmlFileStorageProviderData("XmlStorage", "EnterpriseLibrary.Data.config"), new XmlSerializerTransformerData("DataBuilder")));
			return settings;
		}

		private static DatabaseSettings GenerateDataSettings()
		{
			DatabaseSettings settings = new DatabaseSettings();

			settings.DefaultInstance = "Service_Dflt";

			settings.DatabaseTypes.Add( new DatabaseTypeData("OleDb", typeof(OleDbDatabase).AssemblyQualifiedName));

			ConnectionStringData data = new ConnectionStringData("NewDatabase");
			data.Parameters.Add(new ParameterData("Provider", "SQLOLEDB"));
			data.Parameters.Add(new ParameterData("Data Source","localhost"));
			data.Parameters.Add(new ParameterData("Database","Northwind"));
			data.Parameters.Add(new ParameterData("UID", "EntLib"));
			data.Parameters.Add(new ParameterData("PWD", "EntLib"));
			settings.ConnectionStrings.Add(data);

			data = new ConnectionStringData("DbWithSqlServerAuthn");
			data.Parameters.Add(new ParameterData("Provider", "SQLOLEDB"));
			data.Parameters.Add(new ParameterData("Data Source", "localhost"));
			data.Parameters.Add(new ParameterData("Database", "Northwind"));
			data.Parameters.Add(new ParameterData("UID", "sa"));
			data.Parameters.Add(new ParameterData("PWD","mypassword"));
			settings.ConnectionStrings.Add(data);

			data = new ConnectionStringData("Northwind");
			data.Parameters.Add(new ParameterData("Provider", "SQLOLEDB"));
			data.Parameters.Add(new ParameterData("Data Source", "localhost"));
			data.Parameters.Add(new ParameterData("Database", "Northwind"));
			data.Parameters.Add(new ParameterData("UID", "EntLib"));
			data.Parameters.Add(new ParameterData("PWD", "EntLib"));
			//			data.Parameters.Add(new ParameterData("Integrated Security", "SSPI"));
			settings.ConnectionStrings.Add(data);

			data = new ConnectionStringData("EntLibQuickStarts");
			data.Parameters.Add(new ParameterData("Provider", "SQLOLEDB"));
			data.Parameters.Add(new ParameterData("Data Source", "localhost"));
			data.Parameters.Add(new ParameterData("Database", "EntLibQuickStarts"));
			data.Parameters.Add(new ParameterData("UID", "EntLib"));
			data.Parameters.Add(new ParameterData("PWD", "EntLib"));
			//			data.Parameters.Add(new ParameterData("Integrated Security", "SSPI"));
			settings.ConnectionStrings.Add(data);

			data = new ConnectionStringData("NorthwindPersistFalse");
			data.Parameters.Add(new ParameterData("Provider", "SQLOLEDB"));
			data.Parameters.Add(new ParameterData("Data Source", "localhost"));
			data.Parameters.Add(new ParameterData("Database", "Northwind"));
			data.Parameters.Add(new ParameterData("UID","entlib"));
			data.Parameters.Add(new ParameterData("PWD","entlib"));
			data.Parameters.Add(new ParameterData("Persist Security Info", "false"));
			settings.ConnectionStrings.Add(data);

			settings.Instances.Add( new InstanceData("NewDatabase", "OleDb", "NewDatabase"));
			settings.Instances.Add( new InstanceData("Service_Dflt", "OleDb", "Northwind"));
			settings.Instances.Add( new InstanceData("EntLibQS", "OleDb", "EntLibQuickStarts"));
			settings.Instances.Add( new InstanceData("DbWithSqlServerAuthn", "OleDb", "DbWithSqlServerAuthn"));
			settings.Instances.Add( new InstanceData("NorthwindPersistFalse", "OleDb", "NorthwindPersistFalse"));

			return settings;
		}
	}
}
#endif
